"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
require("mocha");
const assert_1 = __importDefault(require("assert"));
const __1 = require("..");
class PlainTransport {
    constructor(server) {
        this.server = server;
    }
    invoke(body) {
        return __awaiter(this, void 0, void 0, function* () {
            const ret = yield this.server.handle(body);
            return JSON.stringify(ret);
        });
    }
    notify(body) {
        this.server.handle(body).catch(console.log);
    }
}
describe('rpc:client:test', () => {
    const server = new __1.Server();
    server.expose('hello', (m) => 'hello world ' + m);
    server.expose('triggerError', () => { throw new Error('e'); });
    const transport = new PlainTransport(server);
    const client = new __1.Client(transport);
    it('test invoke', () => __awaiter(this, void 0, void 0, function* () {
        const ret = yield client.invoke('hello', 'mike');
        assert_1.default(ret, 'hello world mike');
    }));
    it('test method not found', () => __awaiter(this, void 0, void 0, function* () {
        try {
            yield client.invoke('method');
            assert_1.default(false, 'should not access');
        }
        catch (e) {
            assert_1.default(e.code === -32601, 'code not equal');
        }
    }));
    it('test internal errlr', () => __awaiter(this, void 0, void 0, function* () {
        try {
            yield client.invoke('triggerError');
            assert_1.default(false, 'should not access');
        }
        catch (e) {
            assert_1.default(e.code === -32603, 'code not equal');
        }
    }));
    it('test batch call', () => __awaiter(this, void 0, void 0, function* () {
        const ret = yield client.batch().invoke('hello', 'one')
            .notify('hello', 'two')
            .execute();
        assert_1.default(Array.isArray(ret), 'should return array');
        assert_1.default(ret.length === 1, 'should length = 1');
    }));
    it('test invoke through as', () => __awaiter(this, void 0, void 0, function* () {
        const ret = yield client.as().hello('mike');
        assert_1.default(ret, 'hello world mike');
    }));
});
//# sourceMappingURL=test-client.js.map