"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
require("mocha");
const assert_1 = __importDefault(require("assert"));
const __1 = require("..");
describe('rpc:server:test', () => {
    const server = new __1.Server();
    server.expose('hello', (m) => 'hello world ' + m);
    server.expose('triggerError', () => { throw new Error('e'); });
    it('test simple invoke', () => __awaiter(this, void 0, void 0, function* () {
        const call = {
            jsonrpc: '2.0',
            id: 1,
            method: 'hello'
        };
        const ret = yield server.handle(call);
        assert_1.default(ret.result, 'hello world mike');
    }));
    it('test method not found', () => __awaiter(this, void 0, void 0, function* () {
        const call = JSON.stringify({
            jsonrpc: '2.0',
            id: 1,
            method: 'notexist'
        });
        const res = yield server.handle(call);
        assert_1.default(res.error.code, 'should not access');
    }));
    it('test notify', () => __awaiter(this, void 0, void 0, function* () {
        const call = JSON.stringify({
            jsonrpc: '2.0',
            method: 'hello'
        });
        const ret = yield server.handle(call);
        assert_1.default(!ret, 'hello world mike');
    }));
    it('test mixed batch', () => __awaiter(this, void 0, void 0, function* () {
        const call = JSON.stringify([
            {
                jsonrpc: '2.0',
                method: 'hello'
            },
            {
                jsonrpc: '2.0',
                id: 1,
                method: 'notexist'
            },
            {
                jsonrpc: '2.0',
                id: 1,
                method: 'hello'
            }
        ]);
        const ret = yield server.handle(call);
        assert_1.default(Array.isArray(ret), 'response should be array');
        assert_1.default(ret.length === 2, 'response should be length = 2');
    }));
    it('test notify batch', () => __awaiter(this, void 0, void 0, function* () {
        const call = JSON.stringify([
            {
                jsonrpc: '2.0',
                method: 'hello'
            },
            {
                jsonrpc: '2.0',
                method: 'hello'
            },
        ]);
        const ret = yield server.handle(call);
        assert_1.default(!ret, 'response should be undefined');
    }));
});
//# sourceMappingURL=test-server.js.map