"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const client_1 = require("../client");
const pkg = require('../../package.json');
class HttpTransport {
    constructor(endpoint, headers, proxy) {
        this.endpoint = endpoint;
        this.headers = headers;
        this.proxy = proxy;
        this.headers = Object.assign({
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'User-Agent': `${pkg.name}/${pkg.version}`
        }, this.headers);
    }
    invoke(payload) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield axios_1.default.post(this.endpoint, payload, {
                proxy: this.proxy,
                headers: this.headers,
                responseType: 'arraybuffer'
            });
            return res.data.toString();
        });
    }
    notify(payload) {
        axios_1.default.post(this.endpoint, payload, {
            proxy: this.proxy,
            headers: this.headers,
            responseType: 'arraybuffer'
        }).catch(() => { });
    }
}
exports.HttpTransport = HttpTransport;
/**
 * create an rpc client over http
 *
 * @export
 * @param {string} endpoint
 * @param {*} [headers={}]
 * @returns
 */
function createHttpRpcClient(endpoint, headers = {}, proxy) {
    return new client_1.Client(new HttpTransport(endpoint, headers, proxy));
}
exports.createHttpRpcClient = createHttpRpcClient;
//# sourceMappingURL=http.js.map