export interface JsonRpcResponse {
    id?: null | number | string;
    jsonrpc: '2.0';
    result?: any;
    error?: {
        code: number;
        message: string;
        data?: any;
    };
}
export interface JsonRpcRequest {
    method: string;
    id: number | string;
    params?: any[];
    jsonrpc: '2.0';
}
export interface JsonRpcNotify {
    id?: null | undefined;
    method: string;
    params?: any[];
    jsonrpc: '2.0';
}
export declare type JsonRpcMixedBody = JsonRpcRequest | JsonRpcNotify;
export declare class RemoteError extends Error {
    readonly message: string;
    readonly code: number;
    readonly data: any;
    constructor(message?: string, code?: number, data?: any);
    toJSON(): {
        name: string;
        code: number;
        message: string;
        data: any;
    };
}
export declare class ParseError extends Error {
    readonly message: string;
    readonly code: number;
    constructor(message?: string, code?: number);
    toJSON(): {
        name: string;
        code: number;
        message: string;
    };
}
export declare class TransportError extends Error {
    constructor(err: any);
    toJSON(): {
        name: string;
        code: number;
        message: string;
    };
}
export interface Transport {
    invoke(payload: JsonRpcRequest | JsonRpcMixedBody[]): Promise<string>;
    notify(payload: JsonRpcNotify | JsonRpcNotify[]): void;
}
export interface RpcClient {
    invoke(method: string, ...params: any[]): Promise<any>;
    notify(method: string, ...params: any[]): void;
    as<T>(): T;
}
export interface RpcServer {
    on(event: 'exception', handle: (body: any, e: any) => void): void;
    handle(payload: JsonRpcRequest | JsonRpcNotify[]): Promise<JsonRpcResponse>;
    handle(payload: JsonRpcNotify | JsonRpcNotify[]): Promise<undefined>;
    handle(payload: JsonRpcMixedBody[]): Promise<JsonRpcResponse[] | undefined>;
    handle(payload: string): Promise<JsonRpcResponse[] | JsonRpcResponse | undefined>;
    expose(method: string, func: Function): void;
}
